## Arches Querysets 1.0.1 Release Notes

### Bug Fixes and Enhancements

- Allow AliasedData to be iterated over [#134](https://github.com/archesproject/arches-querysets/issues/134)
- Fixes issue with .get_tiles() not properly filtering on graph_slug and resource_ids [138](https://github.com/archesproject/arches-querysets/issues/138)